@@ -11,6 +11,21 @@ examples/simpletest.py for a demo of the usage.  Based on the Arduino library
 at: https://github.com/adafruit/Adafruit-Si4713-Library/
 
 * Author(s): Tony DiCola
+
+**Hardware:**
+
+* `Adafruit Stereo FM Transmitter with RDS/RBDS Breakout - Si4713
+  <https://www.adafruit.com/product/1958>`_ (Product ID: 1958)
+
+
+**Software and Dependencies:**
+
+* Adafruit CircuitPython firmware for the supported boards:
+  https://circuitpython.org/downloads
+
+* Adafruit's Bus Device library:
+  https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
+
 """
 import time
 
@@ -21,7 +36,7 @@ try:
 except ImportError:
     import ustruct as struct
 
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 
 
 __version__ = "0.0.0-auto.0"
@@ -86,14 +101,14 @@ _SI4713_PROP_TX_RDS_FIFO_SIZE = const(0x2C07)
 
 class SI4713:
     """SI4713 RDS FM transmitter.  Initialize by specifying:
-     - i2c: The I2C bus connected to the board.
 
-    Optionally specify:
-     - address: The I2C address if it has been changed.
-     - reset: A DigitalInOut instance connected to the board's reset line,
-              this will be used to perform a soft reset when necessary.
-     - timeout_s: The amount of time (in seconds) to wait for a command to
-                  succeed.  If this timeout is exceed a runtime error is thrown.
+    :param ~busio.I2C i2c: The I2C bus connected to the board.
+    :param int address: The I2C address if it has been changed. Defaults to :const:`0x63`
+    :param ~digitalio.DigitalInOut reset: A DigitalInOut instance connected to
+     the board's reset line, this will be used to perform a soft reset when necessary.
+    :param float timeout_s: The amount of time (in seconds) to wait for a command to
+     succeed. If this timeout is exceed a runtime error is thrown. Defaults to :const:`0.1`
+
     """
 
     # Class-level buffer to reduce allocations and heap fragmentation.
@@ -122,8 +137,8 @@ class SI4713:
         self._device = i2c_device.I2CDevice(i2c, address)
         self.reset()
         # Check product ID.
-        if self._get_product_number() != 13:
-            raise RuntimeError("Failed to find SI4713, check wiring!")
+        if self._get_product_number() != 13 and self._get_product_number() != 21:
+            raise RuntimeError("Failed to find SI4713 or SI4721, check wiring!")
 
     def _read_u8(self, address):
         # Read an 8-bit unsigned value from the specified 8-bit address.
@@ -439,7 +454,7 @@ class SI4713:
         station_length = len(station)
         assert 0 <= station_length <= 96
         # Fire off each 4 byte update of the station value.
-        for i in range(0, station_length, 4):
+        for i in range(0, 8, 4):
             self._BUFFER[0] = _SI4710_CMD_TX_RDS_PS
             self._BUFFER[1] = i // 4
             self._BUFFER[2] = station[i] if i < station_length else 0x00
